@@ -39,7 +39,7 @@ class Deployer:
         """
         Funzione che esegue i comandi specificati in bash_string e ritorna il loro output
         :param bash_string:         stringa contente i comandi (attenzione ai new_line)
-        :return:                    output dei comandi
+        :return:                    dizionario contenente l'exit_code e l'exit_message
         """
 
         # ottengo la shell da utilizzare per le azioni
@@ -70,10 +70,12 @@ class Deployer:
             # un esempio è la lettura da un disco rimovibile rotto, o un modulo kernel buggato
             stdout, _ = proc_handle.communicate()
 
+        return_code = proc_handle.returncode
+
         # elimino il file
         os.unlink(bash_script.name)
 
-        return stdout.decode()
+        return {'exit_code': return_code, 'exit_message': stdout.decode()}
 
     @staticmethod
     def __get_common_prefix_len(path, directory, reflective):
@@ -173,7 +175,7 @@ class Deployer:
         :param action_name:     nome dell'azione che si vuole eseguire
         :throw ActionNotFoundError:  nel caso non venga trovata l'azione richiesta
         :throw RuntimeError:    nel caso ci siano problemi con l'esecuzione
-        :retrun:                lista degli outputs dei singoli comandi che fanno parte dell'azione
+        :return:                dizionario contenente l'exit_code e l'exit_message
         """
         # controllo se l'azione esiste per questo deployer
         if action_name not in self.__config['action']:
