@@ -1,5 +1,4 @@
 import logging
-import os
 import sys
 
 import cherrypy
@@ -7,6 +6,9 @@ import logging.config
 
 
 # registro i tool prima di importare le viste che ne fanno uso
+from .globals import SERVER_VERSION
+
+
 @cherrypy.tools.register('before_request_body')
 def clear_content_type_parsers():
     request = cherrypy.serving.request
@@ -78,4 +80,9 @@ def start_server(config_file, apikey_folder):
 
     # starting server
     cherrypy.engine.start()
+
+    l = logging.getLogger('app')
+    l.info('Started kaomi-server {}'.format(SERVER_VERSION))
+
+
     cherrypy.engine.block()
